==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Sie haben Zwei-Faktor Sicherungs-Codes für Ihr Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Verwende Backup-Code",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Ihre Backup-Codes. Bitte speichern und/oder drucken Sie diese, da diese Codes später nicht mehr gelesen werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Sie die Backup-Codes erneuern, werden die alten Codes automatisch ungültig.",
    "An error occurred while generating your backup codes" : "Beim Erstellen Ihrer Backup-Codes ist ein Fehler aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwenden Sie einen der Backup-Codes, den Sie bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert haben.",
    "Submit" : "Übermitteln",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes generiert. Bitte holen Sie dies für den Fall, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren, nach.",
    "function" : "Funktion"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Sie haben Zwei-Faktor Sicherungs-Codes für Ihr Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Backup-Code verwenden",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Ihre Backup-Codes. Bitte speichern und/oder drucken Sie diese, da diese Codes später nicht mehr gelesen werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Sie die Backup-Codes erneuern, werden die alten Codes automatisch ungültig.",
    "An error occurred while generating your backup codes" : "Beim Erstellen Ihrer Backup-Codes ist ein Fehler aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwenden Sie einen der Backup-Codes, den Sie bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert haben.",
    "Submit" : "Übermitteln"
},
"nplurals=2; plural=(n != 1);");
